defmodule Slax.Chat do
  @moduledoc """
  Context to handle with chat details.
  """

  import Ecto.Query

  alias Slax.Chat.Room
  alias Slax.Repo

  def create_room(attrs) do
    %Room{}
    |> Room.changeset(attrs)
    |> Repo.insert()
  end

  def update_room(%Room{} = room, attrs) do
    room
    |> Room.changeset(attrs)
    |> Repo.update()
  end

  def change_room(room, attrs \\ %{}) do
    Room.changeset(room, attrs)
  end

  def get_first_room! do
    query = from(r in Room, limit: 1, order_by: [asc: :name])
    Repo.one!(query)
  end

  def get_room!(id) do
    Repo.get!(Room, id)
  end

  def list_rooms do
    query = from(r in Room, order_by: [asc: :name])
    Repo.all(query)
  end
end
